@@ -5,6 +5,7 @@ import subprocess
 from tempfile import TemporaryFile, NamedTemporaryFile
 import wave
 import sys
+from .logging_utils import log_conversion
 
 try:
     from StringIO import StringIO
@@ -174,7 +175,7 @@ class AudioSegment(object):
         from the end of the audio segment like a python list.
         This is intentional.
         """
-        max_val = self.frame_count()
+        max_val = int(self.frame_count())
 
         def bounded(val, default):
             if val is None:
@@ -312,7 +313,7 @@ class AudioSegment(object):
             try:
                 return cls._from_safe_wav(file)
             except:
-                pass
+                file.seek(0)
 
         input_file = NamedTemporaryFile(mode='wb', delete=False)
         input_file.write(file.read())
@@ -335,6 +336,8 @@ class AudioSegment(object):
             "-f", "wav",  # output options (filename last)
             output.name
         ]
+        
+        log_conversion(convertion_command)
 
         retcode = subprocess.call(convertion_command, stderr=open(os.devnull))
 
@@ -387,7 +390,10 @@ class AudioSegment(object):
             Codec used to encoding for the destination.
 
         bitrate (string)
-            Bitrate used when encoding destination file. (128, 256, 312k...)
+            Bitrate used when encoding destination file. (64, 92, 128, 256, 312k...)
+            Each codec accepts different bitrate arguments so take a look at the 
+            ffmpeg documentation for details (bitrate usually shown as -b, -ba or 
+            -a:b).
 
         parameters (string)
             Aditional ffmpeg/avconv parameters
@@ -469,7 +475,9 @@ class AudioSegment(object):
         convertion_command.extend([
             "-f", format, output.name,  # output options (filename last)
         ])
-
+        
+        log_conversion(convertion_command)
+        
         # read stdin / write stdout
         subprocess.call(convertion_command,
                         # make converter shut up
@@ -554,6 +562,20 @@ class AudioSegment(object):
                                'channels': channels,
                                'frame_width': frame_width})
 
+    def split_to_mono(self):
+        if self.channels == 1:
+            return [self]
+
+        left_channel = audioop.tomono(self._data, self.sample_width, 1, 0)
+        right_channel = audioop.tomono(self._data, self.sample_width, 0, 1)
+
+        return [self._spawn(data=left_channel,
+                            overrides={'channels': 1,
+                                       'frame_width': self.sample_width}),
+                self._spawn(data=right_channel,
+                            overrides={'channels': 1,
+                                       'frame_width': self.sample_width})]
+
     @property
     def rms(self):
         if self.sample_width == 1:
@@ -579,6 +601,10 @@ class AudioSegment(object):
 
         # since half is above 0 and half is below the max amplitude is divided
         return max_possible_val / 2
+        
+    @property
+    def max_dBFS(self):
+        return ratio_to_db(self.max, self.max_possible_amplitude)
 
     @property
     def duration_seconds(self):
@@ -620,7 +646,7 @@ class AudioSegment(object):
             # it's a no-op, make a copy since we never mutate
             return self._spawn(self._data)
 
-        output = TemporaryFile()
+        output = StringIO()
 
         seg1, seg2 = AudioSegment._sync(self, seg)
         sample_width = seg1.sample_width
