@@ -254,6 +254,21 @@ class AudioSegmentTests(unittest.TestCase):
                                    len(self.seg1) + len(self.seg2) - 100,
                                    tolerance=1)
 
+    def test_split_to_mono(self):
+        seg = self.seg1
+        mono_segments = seg.split_to_mono()
+        seg_lchannel = mono_segments[0]
+        seg_rchannel = mono_segments[1]
+
+        self.assertEqual(len(seg_lchannel), len(seg))
+        self.assertEqual(len(seg_rchannel), len(seg))
+        
+        self.assertEqual(seg_lchannel.frame_rate, seg.frame_rate)
+        self.assertEqual(seg_rchannel.frame_rate, seg.frame_rate)
+
+        self.assertEqual(seg_lchannel.frame_count(), seg.frame_count())
+        self.assertEqual(seg_rchannel.frame_count(), seg.frame_count())
+
     def test_export_as_mp3(self):
         seg = self.seg1
         exported_mp3 = seg.export()
@@ -551,9 +566,22 @@ class AudioSegmentTests(unittest.TestCase):
     def test_zero_length_segment(self):
         self.assertEqual(0, len(self.seg1[0:0]))
 
+    def test_invert(self):
+        s = Sine(100).to_audio_segment()
+        s_inv = s.invert_phase()
+        self.assertFalse(s == s_inv)
+        self.assertTrue(s.rms == s_inv.rms)
+        self.assertTrue(s == s_inv.invert_phase())
+
+    def test_max_dBFS(self):
+        sine_0_dbfs = Sine(1000).to_audio_segment()
+        sine_minus_3_dbfs = Sine(1000).to_audio_segment(volume=-3.0)
+        self.assertAlmostEqual(-0.0, sine_0_dbfs.max_dBFS, 2)
+        self.assertAlmostEqual(-3.0, sine_minus_3_dbfs.max_dBFS, 2)
+
 
 class SilenceTests(unittest.TestCase):
-    
+
     def setUp(self):
         global test1wav
         if not test1wav:
@@ -564,7 +592,12 @@ class SilenceTests(unittest.TestCase):
     def test_detect_completely_silent_segment(self):
         seg = AudioSegment.silent(5000)
         silent_ranges = detect_silence(seg, min_silence_len=1000, silence_thresh=-20)
-        self.assertEqual(silent_ranges, [[0, 4999]])
+        self.assertEqual(silent_ranges, [[0, 5000]])
+
+    def test_detect_tight_silent_segment(self):
+        seg = AudioSegment.silent(1000)
+        silent_ranges = detect_silence(seg, min_silence_len=1000, silence_thresh=-20)
+        self.assertEqual(silent_ranges, [[0, 1000]])
 
     def test_detect_too_long_silence(self):
         seg = AudioSegment.silent(3000)
@@ -577,7 +610,7 @@ class SilenceTests(unittest.TestCase):
 
 
 class GeneratorTests(unittest.TestCase):
-    
+
     def test_with_smoke(self):
         Sine(440).to_audio_segment()
         Square(440).to_audio_segment()
@@ -608,7 +641,7 @@ class GeneratorTests(unittest.TestCase):
 
 
 class NoConverterTests(unittest.TestCase):
-    
+
     def setUp(self):
         self.wave_file = os.path.join(data_dir, 'test1.wav')
         self.mp3_file = os.path.join(data_dir, 'test1.mp3')
@@ -639,7 +672,7 @@ class NoConverterTests(unittest.TestCase):
 
         func = partial(AudioSegment.from_file, self.mp3_file, "mp3")
         self.assertRaises(OSError, func)
-        
+
         func = partial(AudioSegment.from_file, self.mp3_file, format="mp3")
         self.assertRaises(OSError, func)
 
